==> v1.7.7.22.tar.gz: manaplus/src/listeners/playerpostdeathlistener.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2017  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LISTENERS_PLAYERPOSTDEATHLISTENER_H
#define LISTENERS_PLAYERPOSTDEATHLISTENER_H

#include "being/localplayer.h"

#include "gui/dialogsmanager.h"
#include "gui/popupmanager.h"

#include "gui/windows/npcdialog.h"

#include "net/playerhandler.h"

#include "localconsts.h"

extern OkDialog *deathNotice;

/**
  * Listener used for handling death message.
  */
struct PlayerPostDeathListener final : public ActionListener
{
    PlayerPostDeathListener() :
        ActionListener()
    { }

    A_DELETE_COPY(PlayerPostDeathListener)

    void action(const ActionEvent &event A_UNUSED) override final
    {
        if (playerHandler != nullptr)
            playerHandler->respawn();
        deathNotice = nullptr;

        DialogsManager::closeDialogs();

        if (popupManager != nullptr)
            popupManager->closePopupMenu();

        NpcDialog::clearDialogs();
        if (localPlayer != nullptr)
            localPlayer->respawn();
    }
};

#endif  // LISTENERS_PLAYERPOSTDEATHLISTENER_H

==> v1.7.10.28.tar.gz: manaplus/src/listeners/playerpostdeathlistener.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2017  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LISTENERS_PLAYERPOSTDEATHLISTENER_H
#define LISTENERS_PLAYERPOSTDEATHLISTENER_H

#include "being/localplayer.h"

#include "gui/dialogsmanager.h"
#include "gui/popupmanager.h"

#include "gui/windows/npcdialog.h"

#include "net/playerhandler.h"

#include "localconsts.h"

extern OkDialog *deathNotice;

/**
  * Listener used for handling death message.
  */
struct PlayerPostDeathListener final : public ActionListener
{
    PlayerPostDeathListener() :
        ActionListener()
    { }

    A_DELETE_COPY(PlayerPostDeathListener)

    void action(const ActionEvent &event A_UNUSED) override final
    {
        if (playerHandler != nullptr)
            playerHandler->respawn();
        deathNotice = nullptr;

        DialogsManager::closeDialogs();
        PopupManager::closePopupMenu();

        NpcDialog::clearDialogs();
        if (localPlayer != nullptr)
            localPlayer->respawn();
    }
};

#endif  // LISTENERS_PLAYERPOSTDEATHLISTENER_H
